@@ -4,20 +4,22 @@ This module relies on `fontTools <https://pypi.org/project/fonttools/>`_ for
 OTF parsing and subsetting, and on HarfBuzz (via ``uharfbuzz``) for shaping.
 """
 import logging
+from binascii import hexlify
 from dataclasses import dataclass
 from io import BytesIO
-from binascii import hexlify
 
 from pyhanko.pdf_utils import generic
 from pyhanko.pdf_utils.font.api import (
-    ShapeResult, FontEngine, FontEngineFactory
+    FontEngine,
+    FontEngineFactory,
+    ShapeResult,
 )
 from pyhanko.pdf_utils.misc import peek
 from pyhanko.pdf_utils.writer import BasePdfFileWriter
 
 try:
     import uharfbuzz as hb
-    from fontTools import ttLib, subset
+    from fontTools import subset, ttLib
 except ImportError as import_err:  # pragma: nocover
     raise ImportError(
         "pyhanko.pdf_utils.font.opentype requires pyHanko to be installed with "
@@ -180,7 +182,7 @@ def _build_type0_font_from_cidfont(writer, cidfont_obj: 'CIDFont',
     encoding = 'Identity-V' if vertical else 'Identity-H'
 
     cidfont_obj.embed(writer, obj_stream=obj_stream)
-    cidfont_ref = writer.add_object(cidfont_obj)
+    cidfont_ref = writer.add_object(cidfont_obj, obj_stream=obj_stream)
     type0 = generic.DictionaryObject({
         pdf_name('/Type'): pdf_name('/Font'),
         pdf_name('/Subtype'): pdf_name('/Type0'),
@@ -293,8 +295,7 @@ def _read_ps_name(tt: ttLib.TTFont) -> str:
         name_table = tt['name']
         # extract PostScript name from the font's name table
         nr = next(nr for nr in name_table.names if nr.nameID == 6)
-        if nr.encodingIsUnicodeCompatible():
-            ps_name = nr.string.decode('utf-16be')
+        ps_name = nr.toUnicode()
     except StopIteration:  # pragma: nocover
         pass
 
@@ -393,7 +394,7 @@ class GlyphAccumulator(FontEngine):
             )
         self.writing_direction = writing_direction
         self.bcp47_lang_code = bcp47_lang_code
-        self.__subset_created = False
+        self._subset_created = self._write_prepared = False
 
     @property
     def _reverse_cmap(self):
@@ -548,6 +549,7 @@ class GlyphAccumulator(FontEngine):
         stream = generic.StreamObject(
             stream_data=(header + body + footer).encode('ascii')
         )
+        stream.compress()
         return stream
 
     def _extract_subset(self, options=None):
@@ -583,9 +585,11 @@ class GlyphAccumulator(FontEngine):
             font will be overwritten by the generated subset.
         """
 
-        if not self.__subset_created:
+        if self._write_prepared:
+            return
+        if not self._subset_created:
             self._extract_subset()
-            self.__subset_created = True
+            self._subset_created = True
         writer = self.writer
         obj_stream = self.obj_stream
         by_cid = iter(sorted(self._glyphs.values(), key=lambda t: t[0]))
@@ -599,6 +603,7 @@ class GlyphAccumulator(FontEngine):
         )
         # use our preallocated font ref
         writer.add_object(type0, obj_stream, idnum=self._font_ref.idnum)
+        self._write_prepared = True
 
     def as_resource(self) -> generic.IndirectObject:
         return self._font_ref
@@ -743,9 +748,11 @@ class FontDescriptor(generic.DictionaryObject):
             pdf_name('/Flags'): generic.NumberObject(0b110),
             pdf_name('/StemV'): generic.NumberObject(stemv),
             pdf_name('/ItalicAngle'): generic.FloatObject(
-                tt['post'].italicAngle
+                getattr(tt['post'], 'italicAngle', 0)
             ),
-            pdf_name('/CapHeight'): generic.NumberObject(os2.sCapHeight)
+            pdf_name('/CapHeight'): generic.NumberObject(
+                getattr(os2, 'sCapHeight', 750)
+            )
         })
 
 
@@ -784,9 +791,18 @@ class GlyphAccumulatorFactory(FontEngineFactory):
     Will be guessed by HarfBuzz if not specified.
     """
 
+    create_objstream_if_needed: bool = True
+    """
+    Create an object stream to hold this glyph accumulator's assets if no
+    object stream is passed in, and the writer supports object streams.
+    """
+
     def create_font_engine(self, writer: 'BasePdfFileWriter',
                            obj_stream=None) -> GlyphAccumulator:
         fh = open(self.font_file, 'rb')
+        if obj_stream is None and writer.stream_xrefs and \
+                self.create_objstream_if_needed:
+            obj_stream = writer.prepare_object_stream()
         return GlyphAccumulator(
             writer=writer, font_handle=fh,
             font_size=self.font_size, ot_script_tag=self.ot_script_tag,
