@@ -1602,7 +1602,9 @@ def _allow_appearance_update(old_field, new_field, old: HistoricalResolver,
         return
 
     if not isinstance(new_ap_val, generic.DictionaryObject):
-        raise SuspiciousModification('/AP should point to a dictionary')
+        raise SuspiciousModification(
+            'AP entry should point to a dictionary'
+        )
 
     # we *never* want to whitelist an update for an existing
     # stream object (too much potential for abuse), so we insist on
@@ -1713,10 +1715,6 @@ def _walk_page_tree_annots(old_page_root, new_page_root,
                     f"Annotations {deleted_annots} were deleted."
                 )
 
-            if not added_annots:
-                # nothing to do
-                continue
-
             # look up the names of the associated form field(s)
             # if any of the refs are not in the list
             # -> unrelated annotation -> bail
@@ -1735,7 +1733,8 @@ def _walk_page_tree_annots(old_page_root, new_page_root,
             # not much we can do.
             field_name = None
             if len(added_annots) == 1:
-                field_name = field_name_dict[next(iter(added_annots))]
+                uniq_annot_ref, = added_annots
+                field_name = field_name_dict[uniq_annot_ref]
 
             # Make sure the page dictionaries are the same, so that we
             #  can safely clear them for modification across ALL paths
@@ -2053,6 +2052,13 @@ class StandardDiffPolicy(DiffPolicy):
               field_mdp_spec: Optional[FieldMDPSpec] = None,
               doc_mdp: Optional[MDPPerm] = None) -> DiffResult:
 
+        if doc_mdp == MDPPerm.ANNOTATE:
+            logger.warning(
+                "StandardDiffPolicy was not designed to support "
+                "DocMDP level 3 (MDPPerm.ANNOTATE). Unexpected validation "
+                "results may occur."
+            )
+
         if self.reject_object_freeing:
             freed = new.refs_freed_in_revision()
             if freed:
